/************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include <X11/Xlib.h>
#include "pixels.h"

/************************************************************************/

#define MIN_INTERVAL 0.01

// max number of points sampled
#define MAX_N_POINTS 10000 // Set this to anything you want.

/************************************************************************/

float start_time = 0;

void init_my_clock()
{
  struct timespec the_tp;

  clock_gettime( CLOCK_MONOTONIC, &the_tp );
  start_time = ((float) (the_tp.tv_sec)) + 1.0e-9*the_tp.tv_nsec;
}

/************************************************************************/

float read_my_clock()
{
  struct timespec the_tp;

  clock_gettime( CLOCK_MONOTONIC, &the_tp );
  return ((float) (the_tp.tv_sec)) + 1.0e-9*the_tp.tv_nsec - start_time;
}

/************************************************************************/

main( argc, argv )
int argc;
char **argv;
{
  int i;
  int mouse_position[2];
  unsigned int buttons;
  float array[MAX_N_POINTS][3];
  FILE *stream;
  int n_points;
  Window w1;
  Window x_create_window();
  float last_time;
  float now;
  float z;

  init_my_clock();
  last_time = read_my_clock();
  x_init_graphics();
  w1 = x_create_window( "w1", 0, 0, 700, 700 );
  x_map_window( w1 );

  /* Wait for button press */
  printf( "Waiting for button press.\n" );
  for(;;)
    {
      buttons = x_read_mouse( w1, mouse_position );
      if ( buttons )
	{
	  last_time = read_my_clock();
	  array[0][0] = last_time;
	  array[0][1] = mouse_position[0];
	  array[0][2] = mouse_position[1];
	  break;
	}
    }

  /* Wait for button press */
  printf( "Acquiring data.\n" );
  for( i = 1; i < MAX_N_POINTS; i++ )
    {
      // wait for next point
      for( ; ; )
	{
	  now = read_my_clock();
	  if ( now - last_time < MIN_INTERVAL )
	    {
	      for( z = 0; z < 10000.0; z += 1.0 )
		;
	    }
	  else
	    {
	      last_time = now;
	      break;
	    }
	}
      buttons = x_read_mouse( w1, mouse_position );
      if ( buttons == 0 )
	break;
      array[i][0] = now;
      array[i][1] = mouse_position[0];
      array[i][2] = mouse_position[1];
      x_draw_line( w1, (int) (array[i-1][1]), (int) (array[i-1][2]),
		   (int) (array[i][1]), (int) (array[i][2]),
		  SET, 1 );
    }
  n_points = i;

  stream = fopen( "mouse.data", "w" );
  if ( stream == NULL )
    {
      fprintf( stderr, "Can't open output file.\n" );
      exit( -1 );
    }
  for( i = 0; i < n_points; i++ )
    fprintf( stream, "%g %g %g\n",
	     array[i][0], array[i][1], array[i][2] );
  fclose( stream );

  printf( "Press RETURN to quit.\n" );
  getchar();
}
